@@ -2,8 +2,6 @@ package cmd
 
 import (
 	"fmt"
-	"sort"
-	"strings"
 
 	"github.com/spf13/cobra"
 
@@ -13,6 +11,7 @@ import (
 type managedCmdConfig struct {
 	filter    *chezmoi.EntryTypeFilter
 	pathStyle chezmoi.PathStyle
+	tree      bool
 }
 
 func (c *Config) newManagedCmd() *cobra.Command {
@@ -30,6 +29,7 @@ func (c *Config) newManagedCmd() *cobra.Command {
 	managedCmd.Flags().VarP(c.managed.filter.Exclude, "exclude", "x", "Exclude entry types")
 	managedCmd.Flags().VarP(c.managed.filter.Include, "include", "i", "Include entry types")
 	managedCmd.Flags().VarP(&c.managed.pathStyle, "path-style", "p", "Path style")
+	managedCmd.Flags().BoolVarP(&c.managed.tree, "tree", "t", c.managed.tree, "Print paths as a tree")
 
 	return managedCmd
 }
@@ -48,7 +48,7 @@ func (c *Config) runManagedCmd(cmd *cobra.Command, args []string, sourceState *c
 		}
 	}
 
-	var paths []string
+	var paths []fmt.Stringer
 	_ = sourceState.ForEach(
 		func(targetRelPath chezmoi.RelPath, sourceStateEntry chezmoi.SourceStateEntry) error {
 			if !c.managed.filter.IncludeSourceStateEntry(sourceStateEntry) {
@@ -77,26 +77,23 @@ func (c *Config) runManagedCmd(cmd *cobra.Command, args []string, sourceState *c
 				}
 			}
 
-			var path string
+			var path fmt.Stringer
 			switch c.managed.pathStyle {
 			case chezmoi.PathStyleAbsolute:
-				path = c.DestDirAbsPath.Join(targetRelPath).String()
+				path = c.DestDirAbsPath.Join(targetRelPath)
 			case chezmoi.PathStyleRelative:
-				path = targetRelPath.String()
+				path = targetRelPath
 			case chezmoi.PathStyleSourceAbsolute:
-				path = c.SourceDirAbsPath.Join(sourceStateEntry.SourceRelPath().RelPath()).String()
+				path = c.SourceDirAbsPath.Join(sourceStateEntry.SourceRelPath().RelPath())
 			case chezmoi.PathStyleSourceRelative:
-				path = sourceStateEntry.SourceRelPath().RelPath().String()
+				path = sourceStateEntry.SourceRelPath().RelPath()
 			}
 			paths = append(paths, path)
 			return nil
 		},
 	)
 
-	sort.Strings(paths)
-	builder := strings.Builder{}
-	for _, path := range paths {
-		fmt.Fprintln(&builder, path)
-	}
-	return c.writeOutputString(builder.String())
+	return c.writePaths(stringersToStrings(paths), writePathsOptions{
+		tree: c.managed.tree,
+	})
 }
